#
# tajik.py <Peter.Bienstman@gmail.com>
#

from mnemosyne.libmnemosyne.gui_translator import _
from mnemosyne.libmnemosyne.language import Language


class Tajik(Language):

    name = _("Tajik")
    used_for = "tg"
    feature_description = _("Google translation.")
