#
# lao.py <Peter.Bienstman@gmail.com>
#

from mnemosyne.libmnemosyne.gui_translator import _
from mnemosyne.libmnemosyne.language import Language


class Lao(Language):

    name = _("Lao")
    used_for = "lo"
    feature_description = _("Google translation.")
